<?php

class YResilience_Variables {

  public static function variable_get_names() {

    return array(
      'website_id',                   // (int)    The Website ID.
      'api_key',                      // (string) The Website's API Key.
      'enabled',                      // (bool)   Whether the whole plugin is enabled or not.
      'last_heartbeat',               // (int)    The timestamp of the last heartbeat that fired.
      'last_error_msg',               // (string) Last error message, if any.
      'last_update_method',           // (string) manual or cron.
      'last_update_at',               // (string) manual or cron.
      'init_js',                      // (string) ad_server object
    );
  }

  public static function is_valid( $name ) {
    if ( in_array( $name, self::variable_get_names() ) ) {
      return true;
    }
    return false;
  }

  /**
   * Returns the requested variable.  Looks in yresilience_variables.
   *
   * @param string $name Variable name
   * @param mixed $default (optional)
   */
  public static function variable_get( $name, $default = false ) {
    if ( self::is_valid( $name ) ) {
      return variable_get( "yresilience_$name", $default );
    }

    trigger_error( sprintf( 'Invalid Yavli Resilience variable name: %s', $name ), E_USER_WARNING );

    return $default;
  }

  /**
   * Updates the single given variable.  Updates yresilience_variables.
   *
   * @param string $name Variable name
   * @param mixed $value Variable value
   */
  public static function variable_set( $name, $value ) {
    if ( self::is_valid( $name ) ) {
      return variable_set( "yresilience_$name", $value );
    }

    trigger_error( sprintf( 'Invalid Yavli Resilience variable name: %s', $name ), E_USER_WARNING );

    return false;
  }

  /**
   * Updates the multiple given variables.  Updates yresilience_variables.
   *
   * @param array $array array( variable name => variable value, ... )
   */
  public static function variables_set( $array ) {
    $result = true;
    $names = array_keys( $array );

    $unknown_names = array_diff( $names, self::variable_get_names() );

    foreach ( $unknown_names as $unknown_name ) {
      trigger_error( sprintf( 'Invalid Yavli Resilience variable name: %s', $unknown_name ), E_USER_WARNING );
      unset( $array[ $unknown_name ] );
      $result = false;
    }

    $names = array_diff( $names, $unknown_names );

    foreach ( $names as $name ) {
      $result = self::variable_set( $name, $array[ $name ] ) && $result;;
    }
    return $result;
  }

  /**
   * Deletes the given variable.  May be passed multiple variable names as an array.
   * Updates yresilience_variables.
   *
   * @param string|array $names
   */
  public static function variable_del( $names ) {
    $result = true;
    $names  = (array) $names;

    foreach ( $names as $name ) {
      if ( ! self::is_valid( $name ) ) {
        trigger_error( sprintf( 'Invalid Yavli Resilience variable name: %s', $name ), E_USER_WARNING );

        $result = false;
      }
      $result = variable_del( "yresilience_$name") && $result;
    }
    return $result;
  }

}
